<?php
/*
Plugin Name: Yard Plugin
Description: Displays a Yard calendar in your WordPress installation. Click "Manage your calendar" for the documentation.
Version: 1.04
Author: <a href="https://www.yard.global/events/integrate/plugin/" target="_blank">Team Yard</a> | <a href="https://www.yard.global/events/manage/" target="_blank">Manage your calendar</a>
Author URI: https://www.yard.global
*/

if (!defined('ABSPATH')) {
    exit; // Exit if accessed directly
}

if ($_SERVER['HTTP_HOST'] == "www-dev.yard.global") {
    $plugin_settings['environment'] = "dev";
} else {
    $plugin_settings['environment'] = "live";
}

if ($plugin_settings['environment'] == "dev") {
	// dev
	$plugin_settings['hostname'] = "https://www-dev.yard.global";
} else {
	// live
	$plugin_settings['hostname'] = "https://www.yard.global";
}





// Enqueue plugin CSS
function yard_enqueue_styles() {
    wp_enqueue_style('yard-plugin-style', plugin_dir_url(__FILE__) . 'yard-plugin.css');
}
add_action('wp_enqueue_scripts', 'yard_enqueue_styles');


function yard_fetch_events($params) {
    global $plugin_settings;

    $remote_url = $plugin_settings['hostname'].'/api/v1/get-events/?code='.trim(strip_tags($params['code']));

    if ($params['city'] != '') {
        $remote_url .= '&city='.trim(strip_tags($params['city']));
    }

    if ($params['country'] != '') {
        $remote_url .= '&country='.trim(strip_tags($params['country']));
    }

    if ($params['topic'] != '') {
        $remote_url .= '&topic='.trim(strip_tags($params['topic']));
    }

    $response = wp_remote_get( $remote_url, array(
        'timeout' => 30, // set timeout to 30 seconds
    ) );

    #var_dump( $response );

    if (is_wp_error($response)) {
        return '<p>Unable to retrieve events. You can lookup events also here: <a href="'.$plugin_settings['hostname'].'/events/?show=search-form" target="_blank">Yard Events</a></p>';
    }

    $response_body = json_decode(wp_remote_retrieve_body($response), true);

    if (empty($response_body) || !isset($response_body['events'])) {
        return '<p>No events found or invalid API response.</p>';
    }

    $events = $response_body['events'];

    if (empty($events)) {
        return '<p>No events found.</p>';
    }
    ?>
    
    <div class="yard-wrapper">
        <div class="events-container">
            <?php foreach($events as $key => $event):?>
                <a href="<?php echo esc_url($event['permalink']);?>" target="_blank" class="event-item">                
                    <?php if ($event['websitethumbnailhostname'] != '' && $event['websitethumbnailurl']):?>
                        <img src="<?php echo esc_html($event['websitethumbnailhostname']);?><?php echo esc_html($event['websitethumbnailurl']);?>">
                    <?php endif;?>
                    
                    <h2 class="event-title"><?php echo esc_html($event['title']);?></h2>
                    <span class="event-outputdate"><?php echo esc_html($event['outputdate']);?></span><br>
                    <span class="event-location">
                        <?php if($event['city']):?>
                            <?php echo esc_html($event['city']);?>
                            <?php if($event['country']):?>
                                (<?php echo esc_html($event['country']);?>)
                            <?php endif;?>
                            <?php if($event['offsite'] == '1'):?>
                                and virtual
                            <?php endif;?>
                        <?php else:?>
                            virtual
                        <?php endif;?>
                    </span><br>
                    </a>
            <?php endforeach;?>
        </div>

        <?php if (count($events) == 40):?>
            <!--a href="https://www.yard.global/events/?topic=web3" style="margin-top:1rem; padding: 0 1rem; display:block;" target="_blank">
                Find even more events on Yard. Search form
            </a-->
        <?php endif;?>

        <div class="events-copyright">
            This calendar is powered by <a href="<?php echo $plugin_settings['hostname'];?>" target="_blank"><img src="<?php echo $plugin_settings['hostname'];?>/wp-content/uploads/2024/09/yard-logo-dark.svg" style="height:30px; width:77px; margin-left:4px; margin-right:4px;"></a>  with generous support of sponsors. <a href="<?php echo $plugin_settings['hostname'];?>/events/integrate/?from=plugin" target="_blank">Integrate a Yard calendar</a>
        </div>
    </div>
    
    <?php
    /*
    echo "<pre>";
    var_dump( $events );
    echo "</pre>";
    */

    return $output;
}





function yard_events_shortcode($atts) {
    $atts = shortcode_atts(
        array(
            'code' => '', // Default value for 'code' parameter
            'city' => '',
            'country' => '',
            'topic' => ''
        ), 
        $atts, 
        'yard_plugin'
    );

    return yard_fetch_events($atts);
}
add_shortcode('yard_plugin', 'yard_events_shortcode');





// update plugin prompt
add_filter('pre_set_site_transient_update_plugins', 'yard_check_for_plugin_update');

// /wp-admin/update-core.php?force-check=1
function yard_check_for_plugin_update($transient) {
    global $plugin_settings;

    if (empty($transient->checked)) {
        return $transient;
    }

    // URL to the remote WordPress JSON endpoint
    $remote_url = $plugin_settings['hostname'].'/api/v1/get-plugin-version/';

    // Fetch the data from the remote WordPress REST API
    $response = wp_remote_get($remote_url, array('timeout' => 30));

    // Handle errors in the request
    if (is_wp_error($response)) {
        error_log('Error fetching plugin version data: ' . $response->get_error_message());
        return $transient; // Return early if there's an error
    }

    // Retrieve and decode the JSON body
    $body = wp_remote_retrieve_body($response);
    $plugin_data = json_decode($body, true);

    // Check if the JSON decoding was successful
    if (json_last_error() !== JSON_ERROR_NONE) {
        error_log('JSON decoding error: ' . json_last_error_msg());
        return $transient; // Return early if there was an error decoding JSON
    }

    // Check the current version against the version retrieved from the API
    $plugin_slug = 'yard-plugin/yard-plugin.php'; // Replace with your actual plugin path
    $current_version = $transient->checked[$plugin_slug]; // Current installed version

    if (version_compare($current_version, $plugin_data['version'], '<')) {
        // Build the plugin update information
        $plugin_info = new stdClass();
        $plugin_info->new_version = $plugin_data['version'];
        $plugin_info->slug = 'yard-plugin'; // Plugin slug
        $plugin_info->url = $plugin_settings['hostname']; // URL to the plugin's page
        $plugin_info->package = $plugin_data['download_url']; // Download URL for the updated version

        // Add the update information to the transient
        $transient->response[$plugin_slug] = $plugin_info;
    }

    return $transient;
}






// display plugin info
add_filter('plugins_api', 'yard_plugin_information', 20, 3);

function yard_plugin_information($res, $action, $args) {
    global $plugin_settings;

    $plugin_slug = 'yard-plugin'; // Your plugin slug

    if ($action !== 'plugin_information' || $args->slug !== $plugin_slug) {
        return $res;
    }

    // URL to the remote WordPress REST API endpoint
    $remote_url = $plugin_settings['hostname'].'/api/v1/get-plugin-version/';

    // Fetch the data from the remote WordPress REST API
    $response = wp_remote_get($remote_url, array('timeout' => 30));

    // Handle errors in the request
    if (is_wp_error($response)) {
        error_log('Error fetching plugin data: ' . $response->get_error_message());
        return $res; // Return early if there's an error
    }

    // Retrieve and decode the JSON body
    $body = wp_remote_retrieve_body($response);
    $plugin_data = json_decode($body, true);

    // Check if the JSON decoding was successful
    if (json_last_error() !== JSON_ERROR_NONE) {
        error_log('JSON decoding error: ' . json_last_error_msg());
        return $res; // Return early if there was an error decoding JSON
    }

    // Build the plugin information response
    $res = new stdClass();
    $res->name = 'Yard Plugin';
    $res->slug = $plugin_slug;
    $res->version = $plugin_data['version'];
    $res->author = '<a href="'.$plugin_settings['hostname'].'/events/integrate/plugin/" target="_blank">Team Yard</a>';
    $res->requires = $plugin_data['requires'];
    #$res->tested = $plugin_data['tested'];
    $res->download_link = $plugin_data['download_url'];
    $res->sections = array(
        'description' => wp_kses_post($plugin_data['description']),
        'changelog' => trim($plugin_data['changelog']),
    );

    return $res;
}

 